Contact us
=================

Contact us via our public gitlab
----------

- If you would like to report bugs or push any changes, you can do this on out [gitlab repository](https://gitlab.com/synsense/sinabs-dynapcnn).
  
Contact us via our Discord channel
----------

- We encourage you to join our [SynSense Discord community](https://discord.gg/UkYWnuQPZh) to get in touch with the maintainers and other users.

